@@ -44,6 +44,7 @@ class CogEnvDecoder:
         self._done = None
         self._info = None
         self._action = [0, 0, 0, 0]
+        self._load = 0 #Check whether the action has been loaded
         if env_name == 'RealGame.exe':
             data = open("RealGame_Data/data.txt", "w")
             data.write(str(mat_num))
@@ -285,7 +286,15 @@ class CogEnvDecoder:
         done = False
         while done == False and self._end_thread == False:
             #print(done)
+            #if np.count_nonzero(np.asarray(self._action)) != 4 and self._load == 0:
+            #    self._load = 1
+                #print('here')
+
             obs, reward, done, info = self._env.step(self._action)
+            #if self._load == 1:
+                #print(self._action)
+            #    self._action = [0, 0, 0, 0]
+            #print(self._action)
             img = self.read_img()
             depth_img = self.read_depth_img()
             self_pos = self._GetSelfPos(obs)  # Blue one Position
@@ -305,7 +314,7 @@ class CogEnvDecoder:
             collision_info = self._CollCondtion(obs)  # collision times and continuous collision time
             final_obs = [img, self_pos, enemy_pos, self_info, goal1, goal2, goal3, goal4, goal5, collision_info,
                          depth_img]
-            judge_result = [score, flag_ach, enemy_act, enemy_info, dmg, time_taken]
+            judge_result = [score, time_taken, collision_info, dmg, flag_ach, enemy_info, self_info]
             self._obs = final_obs
             self._reward = reward
             self._done = done
@@ -313,6 +322,7 @@ class CogEnvDecoder:
 
 
 
+
     def step_thread_begin(self):
         #self._thread = Thread(target=self._thread_step)
         self._thread = Thread(target=self._thread_step_action)
@@ -324,15 +334,5 @@ class CogEnvDecoder:
 
     def set_action(self, action):
         self._action = action
-
-    def get_obs(self):
-        return self._obs
-
-    def get_reward(self):
-        return self._reward
-
-    def get_done(self):
-        return self._done
-
-    def get_info(self):
-        return self._info
\ No newline at end of file
+        #self._load = 0
+        return self._obs, self._reward, self._done, self._info
